@@ -11,7 +11,7 @@ use Archive::Any::Lite;
 use Carp;
 use CPAN::DistnameInfo;
 
-our $VERSION = '1.00';
+our $VERSION = '1.01';
 $VERSION =~ s/_//; ## no critic
 
 __PACKAGE__->mk_accessors(qw(dist opts tarball distdir d mck));
@@ -114,7 +114,7 @@ sub unpack {
           $vname =~ s/\-TRIAL[0-9]*//;
 
           $me->d->{extracts_nicely} = 1;
-          if ($vname eq $stuff[0]) {
+          if ($vname ne $stuff[0]) {
             $me->d->{error}{extracts_nicely} = "expected $vname but got $stuff[0]";
           }
         } else {
