@@ -7,7 +7,7 @@ use File::stat;
 use ExtUtils::Manifest qw(maniskip);
 $ExtUtils::Manifest::Quiet = 1;
 
-our $VERSION = '1.00';
+our $VERSION = '1.01';
 $VERSION =~ s/_//; ## no critic
 
 our $RespectManiskip = 1;  # for Test::Kwalitee and its friends
@@ -232,6 +232,9 @@ sub _make_maniskip {
       $maniskip = undef;
     }
     if (-f $maniskip_bak_file && !$has_maniskip_bak) {
+      my $mtime = stat($maniskip_bak_file)->mtime;
+      utime $mtime, $mtime, $maniskip_file;
+
       unlink $maniskip_bak_file;  # probably generated by #include_default
     }
     $maniskip;
